@@ -1,4 +1,4 @@
-## Copyright (C) 2006, 2007 David Bateman
+## Copyright (C) 2006-2012 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -17,21 +17,24 @@
 ## <http://www.gnu.org/licenses/>.
 
 function sparseimages (nm, typ)
+  graphics_toolkit ("gnuplot");
+  set_print_size ();
   if (strcmp (typ, "png"))
     set (0, "defaulttextfontname", "*");
   endif
-  if (! isempty (findstr (octave_config_info ("DEFS"), "HAVE_COLAMD"))
-      && ! isempty (findstr (octave_config_info ("DEFS"), "HAVE_CHOLMOD"))
-      && ! isempty (findstr (octave_config_info ("DEFS"), "HAVE_UMFPACK")))
+
+  if (__have_feature__ ("COLAMD")
+      && __have_feature__ ("CHOLMOD")
+      && __have_feature__ ("UMFPACK"))
     if (strcmp(typ,"txt"))
       txtimages (nm, 15, typ);
     else
       if (strcmp (nm, "gplot"))
-	gplotimages ("gplot", typ);
+        gplotimages ("gplot", typ);
       elseif (strcmp (nm, "grid"))
-	femimages ("grid", typ);
+        femimages ("grid", typ);
       else
-	otherimages (nm, 200, typ);
+        otherimages (nm, 200, typ);
       endif
     endif
   else ## There is no sparse matrix implementation available because
@@ -40,22 +43,37 @@ function sparseimages (nm, typ)
   endif
 endfunction
 
-function bury_output ()
+function set_print_size ()
+  image_size = [5.0, 3.5]; # in inches, 16:9 format
+  border = 0;              # For postscript use 50/72
+  set (0, "defaultfigurepapertype", "<custom>");
+  set (0, "defaultfigurepaperorientation", "landscape");
+  set (0, "defaultfigurepapersize", image_size + 2*border);
+  set (0, "defaultfigurepaperposition", [border, border, image_size]);
+endfunction
+
+function hide_output ()
   f = figure (1);
   set (f, "visible", "off");
 endfunction
 
 function gplotimages (nm, typ)
-  bury_output ();
+  hide_output ();
+  if (strcmp (typ, "eps"))
+    d_typ = "-depsc2";
+  else
+    d_typ = cstrcat ("-d", typ);
+  endif
+
   A = sparse ([2,6,1,3,2,4,3,5,4,6,1,5],
-	      [1,1,2,2,3,3,4,4,5,5,6,6], 1, 6, 6);
+              [1,1,2,2,3,3,4,4,5,5,6,6], 1, 6, 6);
   xy = [0,4,8,6,4,2;5,0,5,7,5,7]';
   gplot (A, xy)
-  print (strcat (nm, ".", typ), strcat ("-d", typ))
-  bury_output ();
+  print (cstrcat (nm, ".", typ), d_typ)
+  hide_output ();
 endfunction
 
-function txtimages(nm,n,typ)
+function txtimages(nm, n, typ)
   a = 10*speye(n) + sparse(1:n,ceil([1:n]/2),1,n,n) + ...
       sparse(ceil([1:n]/2),1:n,1,n,n);
   if (strcmp (nm, "gplot") || strcmp (nm, "grid"))
@@ -66,53 +84,59 @@ function txtimages(nm,n,typ)
     fputs (fid, "+---------------------------------+\n");
     fclose (fid);
   elseif (strcmp (nm, "spmatrix"))
-    printsparse(a,strcat("spmatrix.",typ));
+    printsparse(a,cstrcat("spmatrix.",typ));
   else
-    if (!isempty(findstr(octave_config_info ("DEFS"),"HAVE_COLAMD")) &&
-	!isempty(findstr(octave_config_info ("DEFS"),"HAVE_CHOLMOD")))
+    if (__have_feature__ ("COLAMD")
+        && __have_feature__ ("CHOLMOD"))
       if (strcmp (nm, "spchol"))
-	r1 = chol(a);
-	printsparse(r1,strcat("spchol.",typ));
+        r1 = chol(a);
+        printsparse(r1,cstrcat("spchol.",typ));
       elseif (strcmp (nm, "spcholperm"))
-	[r2,p2,q2]=chol(a);
-	printsparse(r2,strcat("spcholperm.",typ));
+        [r2,p2,q2]=chol(a);
+        printsparse(r2,cstrcat("spcholperm.",typ));
       endif
       ## printf("Text NNZ: Matrix %d, Chol %d, PermChol %d\n",nnz(a),nnz(r1),nnz(r2));
     endif
   endif
 endfunction
 
-function otherimages(nm,n,typ)
-  bury_output ();
+function otherimages(nm, n, typ)
+  hide_output ();
+  if (strcmp (typ, "eps"))
+    d_typ = "-depsc2";
+  else
+    d_typ = cstrcat ("-d", typ);
+  endif
+
   a = 10*speye(n) + sparse(1:n,ceil([1:n]/2),1,n,n) + ...
       sparse(ceil([1:n]/2),1:n,1,n,n);
   if (strcmp (nm, "spmatrix"))
     spy(a);
     axis("ij")
-    print(strcat("spmatrix.",typ),strcat("-d",typ))
-    bury_output ();
+    print(cstrcat("spmatrix.",typ), d_typ)
+    hide_output ();
   else
-    if (!isempty(findstr(octave_config_info ("DEFS"),"HAVE_COLAMD")) &&
-	!isempty(findstr(octave_config_info ("DEFS"),"HAVE_CHOLMOD")))
+    if (__have_feature__ ("COLAMD")
+        && __have_feature__ ("CHOLMOD"))
       if (strcmp (nm, "spchol"))
-	r1 = chol(a);
-	spy(r1);
-	axis("ij")
-	print(strcat("spchol.",typ),strcat("-d",typ))
-	bury_output ();
+        r1 = chol(a);
+        spy(r1);
+        axis("ij")
+        print(cstrcat("spchol.",typ), d_typ)
+        hide_output ();
       elseif (strcmp (nm, "spcholperm"))
-	[r2,p2,q2]=chol(a);
-	spy(r2);
-	axis("ij")
-	print(strcat("spcholperm.",typ),strcat("-d",typ))
-	bury_output ();
+        [r2,p2,q2]=chol(a);
+        spy(r2);
+        axis("ij")
+        print(cstrcat("spcholperm.",typ), d_typ)
+        hide_output ();
       endif
       ## printf("Image NNZ: Matrix %d, Chol %d, PermChol %d\n",nnz(a),nnz(r1),nnz(r2));
     endif
   endif
 endfunction
 
-function printsparse(a,nm)
+function printsparse(a, nm)
   fid = fopen (nm,"wt");
   fputs (fid, "\n");
   for i = 1:size(a,1)
@@ -123,9 +147,9 @@ function printsparse(a,nm)
     endif
     for j = 1:size(a,2)
       if (a(i,j) == 0)
-	fprintf(fid,"  ")
+        fprintf(fid,"  ")
       else
-	fprintf(fid," *")
+        fprintf(fid," *")
       endif
     endfor
     fprintf(fid,"\n")
@@ -150,11 +174,17 @@ function printsparse(a,nm)
   fclose(fid);
 endfunction
 
-function femimages (nm,typ)
-  bury_output ();
-  if (!isempty(findstr(octave_config_info ("DEFS"),"HAVE_COLAMD")) &&
-      !isempty(findstr(octave_config_info ("DEFS"),"HAVE_CHOLMOD")) &&
-      !isempty(findstr(octave_config_info ("DEFS"),"HAVE_UMFPACK")))
+function femimages (nm, typ)
+  hide_output ();
+  if (strcmp (typ, "eps"))
+    d_typ = "-depsc2";
+  else
+    d_typ = cstrcat ("-d", typ);
+  endif
+
+  if (__have_feature__ ("COLAMD")
+      && __have_feature__ ("CHOLMOD")
+      && __have_feature__ ("UMFPACK"))
     ## build a rectangle
     node_y = [1;1.2;1.5;1.8;2]*ones(1,11);
     node_x = ones(5,1)*[1,1.05,1.1,1.2,1.3,1.5,1.7,1.8,1.9,1.95,2];
@@ -170,7 +200,7 @@ function femimages (nm,typ)
 
     E = size(elems,1);  #No. of elements
     N = size(nodes,1);  #No. of elements
-    D = size(elems,2);  #dimentions+1
+    D = size(elems,2);  #dimensions+1
 
     ## Plot FEM Geometry
     elemx = elems(:,[1,2,3,1])';
@@ -227,8 +257,8 @@ function femimages (nm,typ)
 
     plot3 (xelems, yelems, velems);
     view (10, 10);
-    print(strcat(nm,".",typ),strcat("-d",typ))
-    bury_output ();
+    print(cstrcat(nm,".",typ), d_typ)
+    hide_output ();
   endif
 endfunction
 
@@ -247,7 +277,12 @@ function sombreroimage (nm, typ)
     return;
   else ## if (!strcmp (typ, "txt"))
 
-    bury_output ();
+    hide_output ();
+    if (strcmp (typ, "eps"))
+      d_typ = "-depsc2";
+    else
+      d_typ = cstrcat ("-d", typ);
+    endif
 
     x = y = linspace (-8, 8, 41)';
     [xx, yy] = meshgrid (x, y);
@@ -255,10 +290,20 @@ function sombreroimage (nm, typ)
     z = sin (r) ./ r;
     unwind_protect
       mesh (x, y, z);
-      title ("Sorry, graphics not available because octave was\\ncompiled without the sparse matrix implementation.");
+      title ("Sorry, graphics are unavailable because Octave was\ncompiled without a sparse matrix implementation.");
     unwind_protect_cleanup
-      print (strcat (nm, ".", typ), strcat ("-d", typ));
-      bury_output ();
+      print (cstrcat (nm, ".", typ), d_typ);
+      hide_output ();
     end_unwind_protect
   endif
 endfunction
+
+## generate something for the texinfo @image command to process
+function image_as_txt(nm)
+  fid = fopen (sprintf ("%s.txt", nm), "wt");
+  fputs (fid, "\n");
+  fputs (fid, "+---------------------------------+\n");
+  fputs (fid, "| Image unavailable in text mode. |\n");
+  fputs (fid, "+---------------------------------+\n");
+  fclose (fid);
+endfunction
