@@ -49,6 +49,7 @@ workspace_view::workspace_view (QWidget *p)
 
   view->setWordWrap (false);
   view->setContextMenuPolicy (Qt::CustomContextMenu);
+  view_previous_row_count = 0;
 
   // Set an empty widget, so we can assign a layout to it.
   setWidget (new QWidget (this));
@@ -75,7 +76,8 @@ workspace_view::workspace_view (QWidget *p)
            this, SLOT(contextmenu_requested (const QPoint&)));
 
   connect (this, SIGNAL (command_requested (const QString&)),
-           p, SLOT (handle_command_double_clicked (const QString&)));
+           p, SLOT (execute_command_in_terminal (const QString&)));
+
 }
 
 workspace_view::~workspace_view (void)
@@ -88,6 +90,12 @@ workspace_view::~workspace_view (void)
   settings->sync ();
 }
 
+void workspace_view::setModel (workspace_model *model)
+{
+  view->setModel (model);
+  _model = model;
+}
+
 void
 workspace_view::closeEvent (QCloseEvent *e)
 {
@@ -96,11 +104,11 @@ workspace_view::closeEvent (QCloseEvent *e)
 }
 
 void
-workspace_view::contextmenu_requested (const QPoint& pos)
+workspace_view::contextmenu_requested (const QPoint& qpos)
 {
   QMenu menu (this);
 
-  QModelIndex index = view->indexAt (pos);
+  QModelIndex index = view->indexAt (qpos);
   QAbstractItemModel *m = view->model ();
 
   // if it isnt Local, Glocal etc, allow the ctx menu
@@ -137,7 +145,7 @@ workspace_view::contextmenu_requested (const QPoint& pos)
       menu.addAction ("stem(" + var_name + ")", this,
                       SLOT (handle_contextmenu_stem ()));
 
-      menu.exec (view->mapToGlobal (pos));
+      menu.exec (view->mapToGlobal (qpos));
     }
 }
 
@@ -195,19 +203,19 @@ workspace_view::handle_contextmenu_rename (void)
 void
 workspace_view::handle_contextmenu_disp (void)
 {
-  relay_contextmenu_command ("disp"); 
+  relay_contextmenu_command ("disp");
 }
 
 void
 workspace_view::handle_contextmenu_plot (void)
 {
-  relay_contextmenu_command ("figure;\nplot"); 
+  relay_contextmenu_command ("figure (); plot");
 }
 
 void
 workspace_view::handle_contextmenu_stem (void)
 {
-  relay_contextmenu_command ("figure;\nstem"); 
+  relay_contextmenu_command ("figure (); stem");
 }
 
 void
@@ -225,6 +233,36 @@ workspace_view::relay_contextmenu_command (const QString& cmdname)
   
       QString var_name = item_data[0].toString ();
 
-      emit command_requested (cmdname + "(" + var_name + ")\n");
+      emit command_requested (cmdname + " (" + var_name + ");");
     }
 }
+
+void
+workspace_view::handle_model_changed (void)
+{
+  // Just modify those rows that have been added rather than go through
+  // the whole list.  For-loop test will handle when number of rows reduced.
+  QFontMetrics fm = view->fontMetrics ();
+  int row_height =  fm.height ();
+  int new_row_count = view->model ()->rowCount ();
+  for (int i = view_previous_row_count; i < new_row_count; i++)
+    view->setRowHeight (i, row_height);
+  view_previous_row_count = new_row_count;
+}
+
+void
+workspace_view::notice_settings (const QSettings *settings)
+{
+  _model->notice_settings (settings); // update colors of model first
+
+  QString tool_tip;
+  tool_tip  =  QString (tr ("View the variables in the active workspace.<br>"));
+  tool_tip +=  QString (tr ("Colors for the storage class:"));
+  for (int i = 0; i < resource_manager::storage_class_chars ().length (); i++)
+    {
+      tool_tip +=  QString ("<div style=\"background-color:%1;color:#000000\">%2</div>")
+               .arg (_model->storage_class_color (i).name ())
+               .arg (resource_manager::storage_class_names ().at (i));
+    }
+  setToolTip (tool_tip);
+}
