@@ -19,12 +19,12 @@
 ## -*- texinfo -*-
 ## @deftypefn {Command} {} doc @var{function_name}
 ## Display documentation for the function @var{function_name}
-## directly from an on-line version of
+## directly from an online version of
 ## the printed manual, using the GNU Info browser.  If invoked without
 ## any arguments, the manual is shown from the beginning.
 ##
 ## For example, the command @kbd{doc rand} starts the GNU Info browser
-## at the @code{rand} node in the on-line version of the manual.
+## at the @code{rand} node in the online version of the manual.
 ##
 ## Once the GNU Info browser is running, help for using it is available
 ## using the command @kbd{C-h}.
@@ -86,13 +86,13 @@ function retval = doc (fname)
     have_fname = ! isempty (fname);
 
     if (have_fname)
-      status = system (sprintf ("%s --index-search %s", cmd, fname));
+      status = system (sprintf ("%s --index-search \"%s\"", cmd, fname));
     endif
 
     if (! (have_fname && status == 0))
       status = system (cmd);
       if (status == 127)
-        warning ("unable to find info program `%s'", info_program ());
+        warning ("unable to find info program '%s'", info_program ());
       endif
     endif
 
@@ -106,6 +106,10 @@ function retval = doc (fname)
 
 endfunction
 
-%!test if exist( info_file ()) != 2 && exist (sprintf ("%s.gz", info_file ())) != 2
-%!       error ("Info file %s or %s.gz does not exist!", info_file (), info_file ());
-%!     endif
+
+%!test
+%! ifile = info_file ();
+%! if (exist (ifile) != 2 && exist (sprintf ("%s.gz", ifile)) != 2)
+%!   error ("Info file %s or %s.gz does not exist!", ifile, ifile);
+%! endif
+
