@@ -45,13 +45,26 @@ function map = hot (n)
 
   if (n == 1)
     map = [1, 1, 1];
-  elseif (n > 1)
-    x = linspace (0, 1, n)';
-    r = (x < 2/5) .* (5/2 * x) ...
-      + (x >= 2/5);
-    g = (x >= 2/5 & x < 4/5) .* (5/2 * x - 1) ...
-      + (x >= 4/5);
-    b = (x >= 4/5) .* (5 * x - 4);
+  elseif (n == 2)
+    map = [1, 1, 1/2
+           1, 1,  1 ];
+  elseif (n > 2)
+    idx = floor (3/8 * n);
+    nel = idx;
+
+    r = ones (n, 1);
+    r(1:idx, 1) = [1:nel]' / nel;
+
+    g = zeros (n, 1);
+    g(idx+1:2*idx, 1) = r(1:idx);
+    g(2*idx+1:end, 1) = 1;
+
+    idx = 2*idx + 1;   # approximately 3/4 *n
+    nel = n - idx + 1;
+
+    b = zeros (n, 1);
+    b(idx:end, 1) = [1:nel]' / nel;
+
     map = [r, g, b];
   else
     map = zeros (0, 3);
