@@ -1,4 +1,4 @@
-## Copyright (C) 2005-2011 Sren Hauberg
+## Copyright (C) 2005-2012 Sren Hauberg
 ##
 ## This file is part of Octave.
 ##
@@ -59,7 +59,7 @@ function entries = tar (tarfile, files, root = ".")
     if (output(end) == "\n")
       output(end) = [];
     endif
-    entries = strsplit (output, "\n");
+    entries = strsplit (output, "\n", false);
     entries = entries';
   endif
 
