@@ -1,4 +1,4 @@
-## Copyright (C) 2007-2011 David Bateman
+## Copyright (C) 2007-2012 David Bateman
 ##
 ## This file is part of Octave.
 ##
@@ -36,8 +36,8 @@
 ##
 ## @example
 ## @group
-## phi = [0 : 15 : 360] * pi / 180;
-## feather (sin (phi), cos (phi))
+## phi = [0 : 15 : 360] * pi/180;
+## feather (sin (phi), cos (phi));
 ## @end group
 ## @end example
 ##
@@ -111,7 +111,7 @@ endfunction
 
 
 %!demo
-%! clf
-%! phi = [0 : 15 : 360] * pi / 180;
-%! feather (sin (phi), cos (phi))
+%! clf;
+%! phi = [0 : 15 : 360] * pi/180;
+%! feather (sin (phi), cos (phi));
 
