@@ -17,18 +17,28 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {@var{name} =} graphics_toolkit ()
+## @deftypefn  {Function File} {@var{name} =} graphics_toolkit ()
+## @deftypefnx {Function File} {@var{name} =} graphics_toolkit (@var{hlist})
+## @deftypefnx {Function File} {} graphics_toolkit (@var{name})
+## @deftypefnx {Function File} {} graphics_toolkit (@var{hlist}, @var{name})
 ## Return the default graphics toolkit.  The default graphics toolkit value
 ## is assigned to new figures.
-## @deftypefnx {Function File} {@var{name} =} graphics_toolkit (@var{hlist})
+## 
+## @code{graphics_toolkit (@var{hlist})}
+## 
 ## Return the graphics toolkits for the figures with handles @var{hlist}.
-## @deftypefnx {Function File} {} graphics_toolkit (@var{name})
+## 
+## @code{graphics_toolkit (@var{name})}
+## 
 ## Set the default graphics toolkit to @var{name}.  If the toolkit is not
 ## already loaded, it is initialized by calling the function
 ## @code{__init_@var{name}__}.
-## @deftypefnx {Function File} {} graphics_toolkit (@var{hlist}, @var{name})
+## 
+## @code{graphics_toolkit (@var{hlist}, @var{name})}
+##
 ## Set the graphics toolkit for the figures with handles @var{hlist} to
 ## @var{name}.
+## 
 ## @seealso{available_graphics_toolkits}
 ## @end deftypefn
 
