@@ -40,12 +40,12 @@ function [h, failed] = __patch__ (p, varargin)
   elseif (isstruct (varargin{1}))
     if (isfield (varargin{1}, "vertices") && isfield (varargin{1}, "faces"))
       args{1} = "faces";
-      args{2} = getfield(varargin{1}, "faces");
+      args{2} = getfield (varargin{1}, "faces");
       args{3} = "vertices";
-      args{4} = getfield(varargin{1}, "vertices");
+      args{4} = getfield (varargin{1}, "vertices");
       args{5} = "facevertexcdata";
       if (isfield (varargin{1}, "facevertexcdata"))
-        args{6} = getfield(varargin{1}, "facevertexcdata");
+        args{6} = getfield (varargin{1}, "facevertexcdata");
       else
         args{6} = [];
       endif
@@ -97,7 +97,7 @@ function [h, failed] = __patch__ (p, varargin)
         if (isnumeric (c))
           if (isvector (c) && numel (c) == numel (x))
             c = c(:);
-          elseif (size (c, 1) != numel (x) && size (c, 2) == numel (x))
+          elseif (rows (c) != numel (x) && columns (c) == numel (x))
             c = c.';
           endif
         endif
@@ -111,7 +111,7 @@ function [h, failed] = __patch__ (p, varargin)
 
       if (isnumeric (c))
 
-        if (ndims (c) == 3 && size (c, 2) == 1)
+        if (ndims (c) == 3 && columns (c) == 1)
           c = permute (c, [1, 3, 2]);
         endif
 
@@ -136,14 +136,14 @@ function [h, failed] = __patch__ (p, varargin)
           args{10} = [];
         elseif (ndims (c) == 3 && size (c, 3) == 3)
           ## CDATA is specified as RGB data
-          if ((size (c, 1) == 1 && size (c, 2) == 1) ...
-              || (size (c, 1) == 1 && size (c, 2) == columns (x)))
+          if ((rows (c) == 1 && columns (c) == 1) ...
+              || (rows (c) == 1 && columns (c) == columns (x)))
             ## Single patch color or per-face color
             args{7} = "facecolor";
             args{8} = "flat";
             args{9} = "cdata";
             args{10} = c;
-          elseif (size (c, 1) == rows (x) && size (c, 2) == columns (x))
+          elseif (rows (c) == rows (x) && columns (c) == columns (x))
             ## Per-vertex color
             args{7} = "facecolor";
             args{8} = "interp";
@@ -209,7 +209,7 @@ function [h, failed] = __patch__ (p, varargin)
   endif
 endfunction
 
-function args = delfields(args, flds)
+function args = delfields (args, flds)
   idx = cellfun (@(x) any (strcmpi (x, flds)), args);
   if (rows (idx) == 1)
     idx = idx | [false, idx(1:end-1)];
@@ -237,13 +237,13 @@ function args = setdata (args)
     vert = args {idx};
   endif
   idx = find (strcmpi (args, "facevertexcdata"), 1, "last") + 1;
-  if (isempty(idx) || idx > nargs)
+  if (isempty (idx) || idx > nargs)
     fvc = [];
   else
     fvc = args {idx};
   endif
   idx = find (strcmpi (args, "facecolor"), 1, "last") + 1;
-  if (isempty(idx) || idx > nargs)
+  if (isempty (idx) || idx > nargs)
     if (!isempty (fvc))
       fc = "flat";
     else
@@ -252,7 +252,7 @@ function args = setdata (args)
     args = {"facecolor", fc, args{:}};
   endif
 
-  nc = size (faces, 1);
+  nc = rows (faces);
   idx = faces .';
   t1 = isnan (idx);
   for i = find (any (t1))
@@ -261,22 +261,22 @@ function args = setdata (args)
   endfor
   x = reshape (vert(:,1)(idx), size (idx));
   y = reshape (vert(:,2)(idx), size (idx));
-  if (size(vert,2) > 2)
+  if (columns (vert) > 2)
     z = reshape (vert(:,3)(idx), size (idx));
   else
     z = [];
   endif
 
-  if (size(fvc, 1) == nc || size (fvc, 1) == 1)
+  if (rows (fvc) == nc || rows (fvc) == 1)
     c = reshape (fvc, [1, size(fvc)]);
   else
-    if (size(fvc, 2) == 3)
-      c = cat(3, reshape (fvc(idx, 1), size(idx)),
-              reshape (fvc(idx, 2), size(idx)),
-              reshape (fvc(idx, 3), size(idx)));
+    if (columns (fvc) == 3)
+      c = cat (3, reshape (fvc(idx, 1), size (idx)),
+               reshape (fvc(idx, 2), size (idx)),
+               reshape (fvc(idx, 3), size (idx)));
     elseif (isempty (fvc))
       c = [];
-    else ## if (size (fvc, 2) == 1)
+    else ## if (columnns (fvc) == 1)
       c = permute (fvc(faces), [2, 1]);
     endif
   endif
@@ -301,19 +301,19 @@ function args = setvertexdata (args)
     y = args {idx};
   endif
   idx = find (strcmpi (args, "zdata"), 1, "last") + 1;
-  if (isempty(idx) || idx > nargs)
+  if (isempty (idx) || idx > nargs)
     z = [];
   else
     z = args {idx};
   endif
   idx = find (strcmpi (args, "cdata"), 1, "last") + 1;
-  if (isempty(idx) || idx > nargs)
+  if (isempty (idx) || idx > nargs)
     c = [];
   else
     c = args {idx};
   endif
   idx = find (strcmpi (args, "facecolor"), 1, "last") + 1;
-  if (isempty(idx) || idx > nargs)
+  if (isempty (idx) || idx > nargs)
     if (!isempty (c))
       fc = "flat";
     else
@@ -326,17 +326,17 @@ function args = setvertexdata (args)
   if (nr == 1 && nc > 1)
     nr = nc;
     nc = 1;
-  end
+  endif
   if (!isempty (z))
     vert = [x(:), y(:), z(:)];
   else
     vert = [x(:), y(:)];
   endif
-  faces = reshape (1:numel(x), nr, nc);
+  faces = reshape (1:numel (x), nr, nc);
   faces = faces';
 
   if (ndims (c) == 3)
-    fvc = reshape (c, size (c, 1) * size (c, 2), size(c, 3));
+    fvc = reshape (c, rows (c) * columns (c), size (c, 3));
   else
     fvc = c(:);
   endif
