@@ -1,4 +1,4 @@
-## Copyright (C) 2009-2011 Tony Richardson, Jaroslav Hajek
+## Copyright (C) 2009-2012 Tony Richardson, Jaroslav Hajek
 ##
 ## This file is part of Octave.
 ##
@@ -24,13 +24,12 @@
 ## representing:
 ##
 ## @example
-## g(x) = f((x-@var{mu}(1))/@var{mu}(2)).
+## g(x) = f( (x - @var{mu}(1)) / @var{mu}(2) )
 ## @end example
 ##
-## @seealso{polyval}
+## @seealso{polyval, polyfit}
 ## @end deftypefn
 
-
 function g = polyaffine (f, mu)
 
    if (nargin != 2)
@@ -70,25 +69,19 @@ function g = polyaffine (f, mu)
 endfunction
 
 
-%!test
-%! f = [1/5 4/5 -7/5 -2];
-%!
-%! mu = [1, 1.2];
-%!
-%! g = polyaffine (f, mu);
-%!
-%! x = linspace (-4, 4, 100);
-%!
-%! assert (polyval(f, x, [], mu), polyval (g, x), 1e-10);
-
 %!demo
 %! f = [1/5 4/5 -7/5 -2];
-%!
 %! g = polyaffine (f, [1, 1.2]);
-%!
-%! x = linspace (-4, 4, 100);
-%!
-%! plot(x, polyval (f, x), x, polyval (g, x));
-%!
+%! x = linspace (-4,4,100);
+%! plot (x,polyval (f, x), x,polyval (g, x));
+%! legend ("original", "affine");
 %! axis ([-4 4 -3 5]);
-%! grid ("on");
+%! grid on;
+
+%!test
+%! f = [1/5 4/5 -7/5 -2];
+%! mu = [1, 1.2];
+%! g = polyaffine (f, mu);
+%! x = linspace (-4,4,100);
+%! assert (polyval (f, x, [], mu), polyval (g, x), 1e-10);
+
