@@ -1,5 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2005, 2006,
-##               2007 Friedrich Leisch
+## Copyright (C) 1995-2012 Friedrich Leisch
 ##
 ## This file is part of Octave.
 ##
@@ -34,16 +33,16 @@ function H = hurst (x)
   endif
 
   if (isscalar (x))
-    error ("hurst: x must not be a scalar")
+    error ("hurst: X must not be a scalar");
   elseif (isvector (x))
     x = reshape (x, length (x), 1);
-  end
+  endif
 
   [xr, xc] = size (x);
 
   s = std (x);
   w = cumsum (x - mean (x));
-  RS = (max(w) - min(w)) ./ s;
+  RS = (max (w) - min (w)) ./ s;
   H = log (RS) / log (xr);
 
 endfunction
