@@ -1,5 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 2000, 2002, 2005, 2006, 2007
-##               Kurt Hornik
+## Copyright (C) 1995-2012 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -49,29 +48,29 @@ function [pval, t, df] = t_test (x, m, alt)
   endif
 
   if (! isvector (x))
-    error ("t_test: x must be a vector");
+    error ("t_test: X must be a vector");
   endif
   if (! isscalar (m))
-    error ("t_test: m must be a scalar");
+    error ("t_test: M must be a scalar");
   endif
 
   n   = length (x);
   df  = n - 1;
   t   = sqrt (n) * (sum (x) / n - m) / std (x);
-  cdf = t_cdf (t, df);
+  cdf = tcdf (t, df);
 
   if (nargin == 2)
     alt  = "!=";
   endif
 
   if (! ischar (alt))
-    error ("t_test: alt must be a string");
+    error ("t_test: ALT must be a string");
   endif
   if (strcmp (alt, "!=") || strcmp (alt, "<>"))
     pval = 2 * min (cdf, 1 - cdf);
-  elseif strcmp (alt, ">")
+  elseif (strcmp (alt, ">"))
     pval = 1 - cdf;
-  elseif strcmp (alt, "<")
+  elseif (strcmp (alt, "<"))
     pval = cdf;
   else
     error ("t_test: option %s not recognized", alt);
